==> awesome_notifications_fcm-0.7.4%2B1.tar.gz: example/lib/main_complete.dart <==
import 'package:flutter/material.dart';

import 'package:awesome_notifications/awesome_notifications.dart';
import 'package:awesome_notifications_fcm_example/routes.dart';

import 'notifications/notification_controller.dart';

main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await NotificationController.initializeLocalNotifications(debug: true);
  await NotificationController.initializeRemoteNotifications(debug: true);
  await NotificationController.getInitialNotificationAction();
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  static final GlobalKey<NavigatorState> navigatorKey =
      GlobalKey<NavigatorState>();

  static const String name = 'Awesome Notifications Fcm - Example App';
  static final Color mainColor = Color(0xFF9D50DD);

  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();

    // Only after at least the action method is set, the notification events are delivered
    NotificationController.initializeNotificationListeners();
  }

  @override
  void dispose() {
    AwesomeNotifications().dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(

        // The navigator key is necessary to allow to navigate through static methods
        navigatorKey: MyApp.navigatorKey,
        title: 'Awesome Notifications FCM',
        color: MyApp.mainColor,
        theme: ThemeData(
            primaryColor: MyApp.mainColor,
            appBarTheme: AppBarTheme(
              brightness: Brightness.light,
              backgroundColor: Colors.white,
              iconTheme: IconThemeData(color: MyApp.mainColor),
              textTheme: TextTheme(
                  headline6: TextStyle(
                      color: MyApp.mainColor, fontWeight: FontWeight.bold)),
            )),
        initialRoute: PAGE_HOME,
        routes: materialRoutes);
  }
}

==> awesome_notifications_fcm-0.7.5-dev.2%2B1.tar.gz: example/lib/main_complete.dart <==
import 'package:flutter/material.dart';

import 'package:awesome_notifications/awesome_notifications.dart';
import 'package:awesome_notifications_fcm_example/routes.dart';

import 'notifications/notification_controller.dart';

main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await NotificationController.initializeLocalNotifications(debug: true);
  await NotificationController.initializeRemoteNotifications(debug: true);
  await NotificationController.getInitialNotificationAction();
  runApp(CompleteApp());
}

class CompleteApp extends StatefulWidget {
  static final GlobalKey<NavigatorState> navigatorKey =
      GlobalKey<NavigatorState>();

  static const String name = 'Awesome Notifications Fcm - Example App';
  static final Color mainColor = Color(0xFF9D50DD);

  @override
  _CompleteAppState createState() => _CompleteAppState();
}

class _CompleteAppState extends State<CompleteApp> {
  @override
  void initState() {
    super.initState();

    // Only after at least the action method is set, the notification events are delivered
    NotificationController.initializeNotificationListeners();
  }

  @override
  void dispose() {
    AwesomeNotifications().dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        // The navigator key is necessary to allow to navigate through static methods
        navigatorKey: CompleteApp.navigatorKey,
        title: 'Awesome Notifications FCM',
        color: CompleteApp.mainColor,
        theme: ThemeData(
            primaryColor: CompleteApp.mainColor,
            textTheme: TextTheme(
              headline6: TextStyle(
                  color: CompleteApp.mainColor, fontWeight: FontWeight.bold
              ),
            ),
            appBarTheme: AppBarTheme(
              backgroundColor: Colors.white,
              iconTheme: IconThemeData(color: CompleteApp.mainColor),
            ),
        ),
        initialRoute: PAGE_HOME,
        routes: materialRoutes);
  }
}
